# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools
Suportada versão 3 de Python

Para conferir qualidade de código:

```console
pipenv run flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
 4. Mock
 5. Pipenv